#include <Arduino.h>
#include <SIM800IPApplication.hpp>
#include <SIM800HostCommunication.hpp>



SIM800IPApplication::SIM800IPApplication() : host()
{
    host.begin(9600);
    
}

bool SIM800IPApplication::openBearerProfile(uint8_t cid)
{
    return host.checkResponce(host.writeCommand("AT+SAPBR=1," + String(cid) + '\r', 1000));
}

bool SIM800IPApplication::closeBearerProfile(uint8_t cid)
{
    return host.checkResponce(host.writeCommand("AT+SAPBR=0," + String(cid) + '\r', 1000));
}

bool SIM800IPApplication::queryBearerProfile(uint8_t cid, BearerProfile *profile)
{    
    //Clear all data
    memset(profile, 0, sizeof(profile));
    
    //Send command
    host.writeCommand("AT+SAPBR=2," + String(cid) + '\r', 0);
    
    //Parse responce
    while(true){
        //Read responce
        String event = host.readEvent(100);
        
        if(event == "OK"){
            return true;
        }else if(event == "ERROR"){
            return false;
        }else if(event.substring(0,6) == "+SAPBR:"){
            
            // event return +SAPBR:<cid>,<status>,<ip_addr>
            
            //Get CID
            profile->cid = event.charAt(7) - '0';
            
            //Get STATUS
            profile->status = static_cast<BearerStatus>(event.charAt(9) - '0');
            
            //Get IP
            profile->ip = event.substring(12, event.length() - 1);

        }
    }
}

bool SIM800IPApplication::setBearerProfile(uint8_t cid, BearerParameters param)
{
    
    return host.checkResponce(host.writeCommand("AT+SAPBR=3," +\
    String(cid) + ",\"" + param.ConParamTag + "\",\"" +\
    param.ConParamValue + "\"\r", 1000));
    
}
